__all__ = [ "pdrutils", "measurement", "modelset"]

VERSION = "2.1.1"
AUTHORS =  'Marc W. Pound, Mark G. Wolfire'
DESCRIPTION="PhotoDissociation Region Toolbox (PDRT), astrophysics analysis tools"
KEYWORDS = "PDR photodissociation astronomy astrophysics"

# easter egg
motto = "Reliable astrophysics at everyday low, low prices! "+ u"\u00AE"

def version():
    """Version of the PDRT code

    :rtype: str
    """
    return VERSION


